# frozen_string_literal: true

require 'colorize'
require 'erb'

module Crep
  class CrashController
    attr_reader :bundle_identifier, :crashes, :app_name, :version, :build, :total_crashes, :template_path

    def initialize(bundle_identifier, top, crash_source, show_only_unresolved, template_path)
      @bundle_identifier = bundle_identifier
      @top = top
      @crash_source = crash_source
      @show_only_unresolved = show_only_unresolved
      @crash_source.configure(bundle_identifier)
      @app_name = @crash_source.app.name
      @template_path = template_path
    end

    def latest_top_crashes
      app_source = HockeyAppAppSource.new
      app_source.configure
      latest_top_crashes_with_app_source(app_source)
    end

    def latest_top_crashes_with_app_source(app_source)
      latest_app = app_source.versions_for_bundle_identifier(@bundle_identifier).first
      top_crashes(latest_app.version, latest_app.build)
    end

    # returns list of top crashes for the given build
    def top_crashes(version, build)
      @version = version
      @build = build
      @crashes = @crash_source.crashes(@top, version, build, @show_only_unresolved)
      @total_crashes = @crash_source.crash_count(version: @version, build: @build)
      report
    end

    private def report
      template = File.read template_path
      renderer = ERB.new template
      puts output = renderer.result(binding)
      output
    end

    private def crash_percentage(crash:, total_crashes:)
      crash.occurrences.to_f / total_crashes.to_f * 100.0
    end
  end
end
